Extract the adjacency matrix of a TRONCO model. The matrix is indexed with colnames/rownames which
represent genotype keys - these can be resolved with function keysToNames. It is possible to
specify a subset of events to build the matrix, a subset of models if multiple reconstruction have
been performed. Also, either the prima facie matrix or the post-regularization matrix can be extracted.
Usage
as.adj.matrix(x, events = as.events(x), models = names(x$model), type = "fit")
Arguments
x
A TRONCO model.
events
A subset of events as of as.events(x), all by default.
models
A subset of reconstructed models, all by default.
type
Either the prima facie ('pf') or the post-regularization ('fit') matrix, 'fit' by default.